@@ -50,10 +50,6 @@ Options for C<OPT_HASH_REF> passed to package B<C<PerlBean::Attribute>> may incl
 
 =over
 
-=item B<C<attribute_name>>
-
-Passed to L<set_attribute_name()>. Mandatory option.
-
 =item B<C<default_value>>
 
 Passed to L<set_default_value()>.
@@ -70,6 +66,10 @@ Passed to L<set_mandatory()>. Defaults to B<0>.
 
 Passed to L<set_method_base()>.
 
+=item B<C<method_factory_name>>
+
+Passed to L<set_method_factory_name()>. Mandatory option.
+
 =item B<C<perl_bean>>
 
 Passed to L<set_perl_bean()>.
