@@ -10,19 +10,32 @@ push(@::bean_desc, {
 C<PerlBean::Dependency::Import> is a class to express C<import> dependencies to classes/modules/files in a C<PerlBean>.
 EOF
         short_description => 'Import dependency in a Perl bean',
-        synopsis => "TODO.n",
+        synopsis => "TODO\n",
     },
     attr_opt => [
         {
-            attribute_name => 'import_list',
+            method_factory_name => 'import_list',
             type => 'MULTI',
-            orderen => 1,
+            ordered => 1,
             short_description => 'the list after the C<dependency_name>',
         },
     ],
     meth_opt => [
         {
             method_name => 'write',
+            body => <<'EOF',
+    my $self = shift;
+    my $fh = shift;
+
+    my $dn = $self->get_dependency_name();
+    my $tail ='';
+
+    if ( $self->get_import_list() ) {
+        $tail .= ' ';
+        $tail .= join( ', ', $self->get_import_list() );
+    }
+    $fh->print( "import $dn$tail;\n" )
+EOF
         },
     ],
 } );
