@@ -8,10 +8,10 @@ my $bean = PerlBean->new( {
 } );
 my $factory = PerlBean::Attribute::Factory->new();
 my $attr = $factory->create_attribute( {
-    attribute_name => 'name',
+    method_factory_name => 'name',
     short_description => 'the name of the athlete',
 } );
-$bean->add_attribute($attr);
+$bean->add_method_factory($attr);
 
 my $bean2 = PerlBean->new( {
     package => 'Cyclist',
@@ -19,10 +19,10 @@ my $bean2 = PerlBean->new( {
 } );
 my $factory = PerlBean::Attribute::Factory->new();
 my $attr2 = $factory->create_attribute( {
-    attribute_name => 'cycle',
+    method_factory_name => 'cycle',
     short_description => 'the cyclist\'s cycle',
 } );
-$bean2->add_attribute($attr2);
+$bean2->add_method_factory($attr2);
 
 my $collection = PerlBean::Collection->new();
 $collection->add_perl_bean($bean);
