@@ -7,28 +7,8 @@ use warnings;
 use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 
-# Used by _value_is_allowed
-our %ALLOW_ISA = (
-);
-
-# Used by _value_is_allowed
-our %ALLOW_REF = (
-);
-
-# Used by _value_is_allowed
-our %ALLOW_RX = (
-);
-
-# Used by _value_is_allowed
-our %ALLOW_VALUE = (
-);
-
-# Used by _value_is_allowed
-our %DEFAULT_VALUE = (
-);
-
 # Package version
-our ($VERSION) = '$Revision: 0.8 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 1.0 $' =~ /\$Revision:\s+([^\s]+)/;
 
 1;
 
@@ -40,7 +20,8 @@ PerlBean::Dependency::Import - Import dependency in a Perl bean
 
 =head1 SYNOPSIS
 
-TODO.n
+TODO
+
 =head1 ABSTRACT
 
 Import dependency in a Perl bean
@@ -75,6 +56,10 @@ Options for C<OPT_HASH_REF> inherited through package B<C<PerlBean::Dependency>>
 
 Passed to L<set_dependency_name()>.
 
+=item B<C<volatile>>
+
+Passed to L<set_volatile()>.
+
 =back
 
 =back
@@ -83,29 +68,61 @@ Passed to L<set_dependency_name()>.
 
 =over
 
-=item write(FILEHANDLE)
+=item exists_import_list(ARRAY)
 
-This method is an implementation from package C<'PerlBean::Dependency'>. Writes code for the dependency. C<FILEHANDLE> is an C<IO::Handle> object.
+Returns the count of items in C<ARRAY> that are in the list after the C<dependency_name>.
 
-=item set_import_list(ARRAY)
+=item get_dependency_name()
 
-Set the list after the C<dependency_name> absolutely. C<ARRAY> is the list value. On error an exception C<Error::Simple> is thrown.
+This method is inherited from package C<PerlBean::Dependency>. Returns the dependency name.
 
-=item set_idx_import_list( INDEX, VALUE )
+=item get_import_list( [ INDEX_ARRAY ] )
 
-Set value in the list after the C<dependency_name>. C<INDEX> is the integer index which is greater than or equal to C<0>. C<VALUE> is the value.
+Returns an C<ARRAY> containing the list after the C<dependency_name>. C<INDEX_ARRAY> is an optional list of indexes which when specified causes only the indexed elements in the ordered list to be returned. If not specified, all elements are returned.
 
-=item set_num_import_list( NUMBER, VALUE )
+=item is_volatile()
 
-Set value in the list after the C<dependency_name>. C<NUMBER> is the integer index which is greater than C<0>. C<VALUE> is the value.
+This method is inherited from package C<PerlBean::Dependency>. Returns whether the dependency is volatile or not.
+
+=item pop_import_list()
+
+Pop and return an element off the list after the C<dependency_name>. On error an exception C<Error::Simple> is thrown.
 
 =item push_import_list(ARRAY)
 
 Push additional values on the list after the C<dependency_name>. C<ARRAY> is the list value. On error an exception C<Error::Simple> is thrown.
 
-=item pop_import_list()
+=item set_dependency_name(VALUE)
 
-Pop and return an element off the list after the C<dependency_name>. On error an exception C<Error::Simple> is thrown.
+This method is inherited from package C<PerlBean::Dependency>. Set the dependency name. C<VALUE> is the value. On error an exception C<Error::Simple> is thrown.
+
+=over
+
+=item VALUE must match regular expression:
+
+=over
+
+=item ^.*[a-zA-Z].*$
+
+=back
+
+=back
+
+=item set_idx_import_list( INDEX, VALUE )
+
+Set value in the list after the C<dependency_name>. C<INDEX> is the integer index which is greater than or equal to C<0>. C<VALUE> is the value.
+
+=item set_import_list(ARRAY)
+
+Set the list after the C<dependency_name> absolutely. C<ARRAY> is the list value. On error an exception C<Error::Simple> is thrown.
+
+=item set_num_import_list( NUMBER, VALUE )
+
+Set value in the list after the C<dependency_name>. C<NUMBER> is the integer index which is greater than C<0>. C<VALUE> is the value.
+
+=item set_volatile(VALUE)
+
+This method is inherited from package C<PerlBean::Dependency>. State that the dependency is volatile. C<VALUE> is the value. On error an exception C<Error::Simple> is thrown.
 
 =item shift_import_list()
 
@@ -115,23 +132,9 @@ Shift and return an element off the list after the C<dependency_name>. On error
 
 Unshift additional values on the list after the C<dependency_name>. C<ARRAY> is the list value. On error an exception C<Error::Simple> is thrown.
 
-=item exists_import_list(ARRAY)
+=item write(FILEHANDLE)
 
-Returns the count of items in C<ARRAY> that are in the list after the C<dependency_name>.
-
-=item get_import_list( [ INDEX_ARRAY ] )
-
-Returns an C<ARRAY> containing the list after the C<dependency_name>. C<INDEX_ARRAY> is an optional list of indexes which when specified causes only the indexed elements in the ordered list to be returned. If not specified, all elements are returned.
-
-=back
-
-=head1 INHERITED METHODS FROM PerlBean::Dependency
-
-=over
-
-=item To access attribute named B<C<dependency_name>>:
-
-set_dependency_name(), get_dependency_name()
+This method is an implementation from package C<PerlBean::Dependency>. Writes code for the dependency. C<FILEHANDLE> is an C<IO::Handle> object.
 
 =back
 
@@ -156,6 +159,7 @@ L<PerlBean::Described>,
 L<PerlBean::Described::ExportTag>,
 L<PerlBean::Method>,
 L<PerlBean::Method::Constructor>,
+L<PerlBean::Method::Factory>,
 L<PerlBean::Style>,
 L<PerlBean::Symbol>
 
@@ -166,6 +170,7 @@ None known (yet.)
 =head1 HISTORY
 
 First development: March 2003
+Last update: September 2003
 
 =head1 AUTHOR
 
@@ -220,95 +225,14 @@ sub _initialize {
     return($self);
 }
 
-sub write {
-    my $self = shift;
-    my $fh = shift;
-
-    my $dn = $self->get_dependency_name();
-    my $tail ='';
-
-    if ( $self->get_import_list() ) {
-        $tail .= ' ';
-        $tail .= join( ', ', $self->get_import_list() );
-    }
-    $fh->print( "import $dn$tail;\n" )
-}
-
-sub set_import_list {
-    my $self = shift;
-
-    # Check if isas/refs/rxs/values are allowed
-    &_value_is_allowed( 'import_list', @_ ) || throw Error::Simple("ERROR: PerlBean::Dependency::Import::set_import_list, one or more specified value(s) '@_' is/are not allowed.");
-
-    # Set the list
-    @{ $self->{PerlBean_Dependency_Import}{import_list} } = @_;
-}
-
-sub set_idx_import_list {
-    my $self = shift;
-    my $idx = shift;
-    my $val = shift;
-
-    # Check if index is a positive integer or zero
-    ( $idx == int($idx) ) || throw Error::Simple("ERROR: PerlBean::Dependency::Import::set_idx_import_list, the specified index '$idx' is not an integer.");
-    ( $idx >= 0 ) || throw Error::Simple("ERROR: PerlBean::Dependency::Import::set_idx_import_list, the specified index '$idx' is not a positive integer or zero.");
-
-    # Check if isas/refs/rxs/values are allowed
-    &_value_is_allowed( 'import_list', $val ) || throw Error::Simple("ERROR: PerlBean::Dependency::Import::set_idx_import_list, one or more specified value(s) '@_' is/are not allowed.");
-
-    # Set the value in the list
-    $self->{PerlBean_Dependency_Import}{import_list}[$idx] = $val;
-}
-
-sub set_num_import_list {
-    my $self = shift;
-    my $num = shift;
-
-    # Check if index is an integer
-    ( $num == int($num) ) || throw Error::Simple("ERROR: PerlBean::Dependency::Import::set_num_import_list, the specified number '$num' is not an integer.");
-
-    # Call set_idx_import_list
-    $self->set_idx_import_list( $num - 1,  );
-}
-
-sub push_import_list {
-    my $self = shift;
-
-    # Check if isas/refs/rxs/values are allowed
-    &_value_is_allowed( 'import_list', @_ ) || throw Error::Simple("ERROR: PerlBean::Dependency::Import::push_import_list, one or more specified value(s) '@_' is/are not allowed.");
-
-    # Push the list
-    push( @{ $self->{PerlBean_Dependency_Import}{import_list} }, @_ );
-}
-
-sub pop_import_list {
-    my $self = shift;
-
-    # Pop an element from the list
-    return( pop( @{ $self->{PerlBean_Dependency_Import}{import_list} } ) );
-}
-
-sub shift_import_list {
-    my $self = shift;
-
-    # Shift an element from the list
-    return( shift( @{ $self->{PerlBean_Dependency_Import}{import_list} } ) );
-}
-
-sub unshift_import_list {
-    my $self = shift;
-
-    # Check if isas/refs/rxs/values are allowed
-    &_value_is_allowed( 'import_list', @_ ) || throw Error::Simple("ERROR: PerlBean::Dependency::Import::unshift_import_list, one or more specified value(s) '@_' is/are not allowed.");
-
-    # Unshift the list
-    unshift( @{ $self->{PerlBean_Dependency_Import}{import_list} }, @_ );
+sub _value_is_allowed {
+    return(1);
 }
 
 sub exists_import_list {
     my $self = shift;
 
-    # Count occurences
+    # Count occurrences
     my $count = 0;
     foreach my $val1 (@_) {
         foreach my $val2 ( @{ $self->{PerlBean_Dependency_Import}{import_list} } ) {
@@ -334,46 +258,88 @@ sub get_import_list {
     }
 }
 
-sub _value_is_allowed {
-    my $name = shift;
+sub pop_import_list {
+    my $self = shift;
 
-    # Value is allowed if no ALLOW clauses exist for the named attribute
-    if ( ! exists( $ALLOW_ISA{$name} ) && ! exists( $ALLOW_REF{$name} ) && ! exists( $ALLOW_RX{$name} ) && ! exists( $ALLOW_VALUE{$name} ) ) {
-        return(1);
-    }
+    # Pop an element from the list
+    return( pop( @{ $self->{PerlBean_Dependency_Import}{import_list} } ) );
+}
+
+sub push_import_list {
+    my $self = shift;
+
+    # Check if isas/refs/rxs/values are allowed
+    &_value_is_allowed( 'import_list', @_ ) || throw Error::Simple("ERROR: PerlBean::Dependency::Import::push_import_list, one or more specified value(s) '@_' is/are not allowed.");
+
+    # Push the list
+    push( @{ $self->{PerlBean_Dependency_Import}{import_list} }, @_ );
+}
+
+sub set_idx_import_list {
+    my $self = shift;
+    my $idx = shift;
+    my $val = shift;
+
+    # Check if index is a positive integer or zero
+    ( $idx == int($idx) ) || throw Error::Simple("ERROR: PerlBean::Dependency::Import::set_idx_import_list, the specified index '$idx' is not an integer.");
+    ( $idx >= 0 ) || throw Error::Simple("ERROR: PerlBean::Dependency::Import::set_idx_import_list, the specified index '$idx' is not a positive integer or zero.");
+
+    # Check if isas/refs/rxs/values are allowed
+    &_value_is_allowed( 'import_list', $val ) || throw Error::Simple("ERROR: PerlBean::Dependency::Import::set_idx_import_list, one or more specified value(s) '@_' is/are not allowed.");
+
+    # Set the value in the list
+    $self->{PerlBean_Dependency_Import}{import_list}[$idx] = $val;
+}
+
+sub set_import_list {
+    my $self = shift;
+
+    # Check if isas/refs/rxs/values are allowed
+    &_value_is_allowed( 'import_list', @_ ) || throw Error::Simple("ERROR: PerlBean::Dependency::Import::set_import_list, one or more specified value(s) '@_' is/are not allowed.");
+
+    # Set the list
+    @{ $self->{PerlBean_Dependency_Import}{import_list} } = @_;
+}
+
+sub set_num_import_list {
+    my $self = shift;
+    my $num = shift;
+
+    # Check if index is an integer
+    ( $num == int($num) ) || throw Error::Simple("ERROR: PerlBean::Dependency::Import::set_num_import_list, the specified number '$num' is not an integer.");
+
+    # Call set_idx_import_list
+    $self->set_idx_import_list( $num - 1, @_ );
+}
+
+sub shift_import_list {
+    my $self = shift;
+
+    # Shift an element from the list
+    return( shift( @{ $self->{PerlBean_Dependency_Import}{import_list} } ) );
+}
+
+sub unshift_import_list {
+    my $self = shift;
+
+    # Check if isas/refs/rxs/values are allowed
+    &_value_is_allowed( 'import_list', @_ ) || throw Error::Simple("ERROR: PerlBean::Dependency::Import::unshift_import_list, one or more specified value(s) '@_' is/are not allowed.");
+
+    # Unshift the list
+    unshift( @{ $self->{PerlBean_Dependency_Import}{import_list} }, @_ );
+}
+
+sub write {
+    my $self = shift;
+    my $fh = shift;
+
+    my $dn = $self->get_dependency_name();
+    my $tail ='';
 
-    # At this point, all values in @_ must to be allowed
-    CHECK_VALUES:
-    foreach my $val (@_) {
-        # Check ALLOW_ISA
-        if ( ref($val) && exists( $ALLOW_ISA{$name} ) ) {
-            foreach my $class ( @{ $ALLOW_ISA{$name} } ) {
-                &UNIVERSAL::isa( $val, $class ) && next CHECK_VALUES;
-            }
-        }
-
-        # Check ALLOW_REF
-        if ( ref($val) && exists( $ALLOW_REF{$name} ) ) {
-            exists( $ALLOW_REF{$name}{ ref($val) } ) && next CHECK_VALUES;
-        }
-
-        # Check ALLOW_RX
-        if ( defined($val) && ! ref($val) && exists( $ALLOW_RX{$name} ) ) {
-            foreach my $rx ( @{ $ALLOW_RX{$name} } ) {
-                $val =~ /$rx/ && next CHECK_VALUES;
-            }
-        }
-
-        # Check ALLOW_VALUE
-        if ( ! ref($val) && exists( $ALLOW_VALUE{$name} ) ) {
-            exists( $ALLOW_VALUE{$name}{$val} ) && next CHECK_VALUES;
-        }
-
-        # We caught a not allowed value
-        return(0);
+    if ( $self->get_import_list() ) {
+        $tail .= ' ';
+        $tail .= join( ', ', $self->get_import_list() );
     }
-
-    # OK, all values are allowed
-    return(1);
+    $fh->print( "import $dn$tail;\n" )
 }
 
