@@ -24,12 +24,8 @@ our %ALLOW_RX = (
 our %ALLOW_VALUE = (
 );
 
-# Used by _value_is_allowed
-our %DEFAULT_VALUE = (
-);
-
 # Package version
-our ($VERSION) = '$Revision: 0.8 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 1.0 $' =~ /\$Revision:\s+([^\s]+)/;
 
 1;
 
@@ -41,7 +37,7 @@ PerlBean::Described::ExportTag - Tag description
 
 =head1 SYNOPSIS
 
-TODO.
+TODO
 
 =head1 ABSTRACT
 
@@ -85,6 +81,18 @@ Passed to L<set_description()>.
 
 =over
 
+=item get_description()
+
+This method is inherited from package C<PerlBean::Described>. Returns the description.
+
+=item get_export_tag_name()
+
+Returns tag's name.
+
+=item set_description(VALUE)
+
+This method is inherited from package C<PerlBean::Described>. Set the description. C<VALUE> is the value. On error an exception C<Error::Simple> is thrown.
+
 =item set_export_tag_name(VALUE)
 
 Set tag's name. C<VALUE> is the value. C<VALUE> may not be C<undef>. On error an exception C<Error::Simple> is thrown.
@@ -101,20 +109,6 @@ Set tag's name. C<VALUE> is the value. C<VALUE> may not be C<undef>. On error an
 
 =back
 
-=item get_export_tag_name()
-
-Returns tag's name.
-
-=back
-
-=head1 INHERITED METHODS FROM PerlBean::Described
-
-=over
-
-=item To access attribute named B<C<description>>:
-
-set_description(), get_description()
-
 =back
 
 =head1 SEE ALSO
@@ -138,6 +132,7 @@ L<PerlBean::Dependency::Use>,
 L<PerlBean::Described>,
 L<PerlBean::Method>,
 L<PerlBean::Method::Constructor>,
+L<PerlBean::Method::Factory>,
 L<PerlBean::Style>,
 L<PerlBean::Symbol>
 
@@ -148,6 +143,7 @@ None known (yet.)
 =head1 HISTORY
 
 First development: March 2003
+Last update: September 2003
 
 =head1 AUTHOR
 
@@ -197,26 +193,6 @@ sub _initialize {
     return($self);
 }
 
-sub set_export_tag_name {
-    my $self = shift;
-    my $val = shift;
-
-    # Value for 'export_tag_name' is not allowed to be empty
-    defined($val) || throw Error::Simple("ERROR: PerlBean::Described::ExportTag::set_export_tag_name, value may not be empty.");
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'export_tag_name', $val ) || throw Error::Simple("ERROR: PerlBean::Described::ExportTag::set_export_tag_name, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{PerlBean_Described_ExportTag}{export_tag_name} = $val;
-}
-
-sub get_export_tag_name {
-    my $self = shift;
-
-    return( $self->{PerlBean_Described_ExportTag}{export_tag_name} );
-}
-
 sub _value_is_allowed {
     my $name = shift;
 
@@ -260,3 +236,23 @@ sub _value_is_allowed {
     return(1);
 }
 
+sub get_export_tag_name {
+    my $self = shift;
+
+    return( $self->{PerlBean_Described_ExportTag}{export_tag_name} );
+}
+
+sub set_export_tag_name {
+    my $self = shift;
+    my $val = shift;
+
+    # Value for 'export_tag_name' is not allowed to be empty
+    defined($val) || throw Error::Simple("ERROR: PerlBean::Described::ExportTag::set_export_tag_name, value may not be empty.");
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'export_tag_name', $val ) || throw Error::Simple("ERROR: PerlBean::Described::ExportTag::set_export_tag_name, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{PerlBean_Described_ExportTag}{export_tag_name} = $val;
+}
+
