@@ -14,7 +14,7 @@ our $AC;
 # Shortcut for singleton's get_str_around_complex_subscripts()
 our $ACS;
 
-# Shortcut for singleton's get_attribute_name_to_method_base_filter()
+# Shortcut for singleton's get_method_factory_name_to_method_base_filter()
 our $AN2MBF;
 
 # Shortcut for singleton's get_str_around_operators()
@@ -41,7 +41,7 @@ our %ALLOW_ISA = (
 
 # Used by _value_is_allowed
 our %ALLOW_REF = (
-    'attribute_name_to_method_base_filter' => {
+    'method_factory_name_to_method_base_filter' => {
         'CODE' => 1,
     },
     'method_operation_filter' => {
@@ -65,10 +65,10 @@ our %ALLOW_RX = (
 our %ALLOW_VALUE = (
 );
 
-# Used by _value_is_allowed
+# Used by _initialize
 our %DEFAULT_VALUE = (
-    'attribute_name_to_method_base_filter' => \&default_attribute_name_to_method_base_filter,
     'indent' => '    ',
+    'method_factory_name_to_method_base_filter' => \&default_method_factory_name_to_method_base_filter,
     'method_operation_filter' => \&default_method_operation_filter,
     'str_after_comma' => ' ',
     'str_around_complex_subscripts' => ' ',
@@ -96,7 +96,7 @@ our %EXPORT_TAGS = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.8 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 1.0 $' =~ /\$Revision:\s+([^\s]+)/;
 
 # Exporter variable
 our @EXPORT = qw(
@@ -151,7 +151,7 @@ By default nothing is exported.
 
 =head2 codegen
 
-This tag contains variables usefull for the actual code generation. You should not need to use this tag.
+This tag contains variables useful for the actual code generation. You should not need to use this tag.
 
 =over
 
@@ -165,7 +165,7 @@ The value which would be obtained through the singleton object's C<get_str_aroun
 
 =item $AN2MBF
 
-The value which would be obtained through the singleton object's C<get_attribute_name_to_method_base_filter()> method.
+The value which would be obtained through the singleton object's C<get_method_factory_name_to_method_base_filter()> method.
 
 =item $AO
 
@@ -209,14 +209,14 @@ Options for C<OPT_HASH_REF> may include:
 
 =over
 
-=item B<C<attribute_name_to_method_base_filter>>
-
-Passed to L<set_attribute_name_to_method_base_filter()>. Defaults to B<\&default_attribute_name_to_method_base_filter>.
-
 =item B<C<indent>>
 
 Passed to L<set_indent()>. Defaults to B<'    '>.
 
+=item B<C<method_factory_name_to_method_base_filter>>
+
+Passed to L<set_method_factory_name_to_method_base_filter()>. Defaults to B<\&default_method_factory_name_to_method_base_filter>.
+
 =item B<C<method_operation_filter>>
 
 Passed to L<set_method_operation_filter()>. Defaults to B<\&default_method_operation_filter>.
@@ -257,7 +257,7 @@ Passed to L<set_str_pre_block_open_curl()>. Defaults to B<' '>.
 
 =over
 
-=item default_attribute_name_to_method_base_filter(ATTRIBUTE)
+=item default_method_factory_name_to_method_base_filter(ATTRIBUTE)
 
 Class method. Default attribute name to method filter. C<ATTRIBUTE> is the attribute name. This method adds a C<_> character to C<ATTRIBUTE> and returns it.
 
@@ -265,30 +265,50 @@ Class method. Default attribute name to method filter. C<ATTRIBUTE> is the attri
 
 Class method. Default method operation filter. C<OPERATION> is the operation name. This method plainly returns the C<OPERATION>.
 
+=item get_indent()
+
+Returns the string used for ONE indentation.
+
+=item get_method_factory_name_to_method_base_filter()
+
+Returns the subroutine that converts an attribute name to the method base.
+
+=item get_method_operation_filter()
+
+Returns the subroutine that formats the method operation.
+
+=item get_str_after_comma()
+
+Returns the string after each comma.
+
+=item get_str_around_complex_subscripts()
+
+Returns the string around "complex" subscripts(inside brackets).
+
+=item get_str_around_operators()
+
+Returns the string around most operators.
+
+=item get_str_between_conditional_and_parenthesis()
+
+Returns the string between conditionals (C<for>, C<if>, C<while>...) and parenthesis.
+
+=item get_str_between_function_and_parenthesis()
+
+Returns the string between function name and its opening parenthesis.
+
+=item get_str_post_block_close_curl()
+
+Returns the string printed after the closing curly of a multi-line BLOCK. Any string C<__IND_BLOCK__> in the value is replaced with the correct block indentation.
+
+=item get_str_pre_block_open_curl()
+
+Returns the string printed before the opening curly of a multi-line BLOCK. Any string C<__IND_BLOCK__> in the value is replaced with the correct block indentation.
+
 =item instance( [ CONSTR_OPT ] )
 
 Always returns the same C<PerlBean::Style> -singleton- object instance. The first time it is called, parameters C<CONSTR_OPT> -if specified- are passed to the constructor.
 
-=item set_attribute_name_to_method_base_filter(VALUE)
-
-Set the subroutine that converts an attribute name to the method base. C<VALUE> is the value. Default value at initialization is C<\&default_attribute_name_to_method_base_filter>. On error an exception C<Error::Simple> is thrown.
-
-=over
-
-=item VALUE must be a reference of:
-
-=over
-
-=item CODE
-
-=back
-
-=back
-
-=item get_attribute_name_to_method_base_filter()
-
-Returns the subroutine that converts an attribute name to the method base.
-
 =item set_indent(VALUE)
 
 Set the string used for ONE indentation. C<VALUE> is the value. Default value at initialization is C<'    '>. On error an exception C<Error::Simple> is thrown.
@@ -305,9 +325,21 @@ Set the string used for ONE indentation. C<VALUE> is the value. Default value at
 
 =back
 
-=item get_indent()
+=item set_method_factory_name_to_method_base_filter(VALUE)
 
-Returns the string used for ONE indentation.
+Set the subroutine that converts an attribute name to the method base. C<VALUE> is the value. Default value at initialization is C<\&default_method_factory_name_to_method_base_filter>. On error an exception C<Error::Simple> is thrown.
+
+=over
+
+=item VALUE must be a reference of:
+
+=over
+
+=item CODE
+
+=back
+
+=back
 
 =item set_method_operation_filter(VALUE)
 
@@ -325,10 +357,6 @@ Set the subroutine that formats the method operation. C<VALUE> is the value. Def
 
 =back
 
-=item get_method_operation_filter()
-
-Returns the subroutine that formats the method operation.
-
 =item set_str_after_comma(VALUE)
 
 Set the string after each comma. C<VALUE> is the value. Default value at initialization is C<' '>. On error an exception C<Error::Simple> is thrown.
@@ -345,10 +373,6 @@ Set the string after each comma. C<VALUE> is the value. Default value at initial
 
 =back
 
-=item get_str_after_comma()
-
-Returns the string after each comma.
-
 =item set_str_around_complex_subscripts(VALUE)
 
 Set the string around "complex" subscripts(inside brackets). C<VALUE> is the value. Default value at initialization is C<' '>. On error an exception C<Error::Simple> is thrown.
@@ -365,10 +389,6 @@ Set the string around "complex" subscripts(inside brackets). C<VALUE> is the val
 
 =back
 
-=item get_str_around_complex_subscripts()
-
-Returns the string around "complex" subscripts(inside brackets).
-
 =item set_str_around_operators(VALUE)
 
 Set the string around most operators. C<VALUE> is the value. Default value at initialization is C<' '>. On error an exception C<Error::Simple> is thrown.
@@ -385,13 +405,9 @@ Set the string around most operators. C<VALUE> is the value. Default value at in
 
 =back
 
-=item get_str_around_operators()
-
-Returns the string around most operators.
-
 =item set_str_between_conditional_and_parenthesis(VALUE)
 
-Set the string between condiftionals (C<for>, C<if>, C<while>...) and parenthesis. C<VALUE> is the value. Default value at initialization is C<' '>. On error an exception C<Error::Simple> is thrown.
+Set the string between conditionals (C<for>, C<if>, C<while>...) and parenthesis. C<VALUE> is the value. Default value at initialization is C<' '>. On error an exception C<Error::Simple> is thrown.
 
 =over
 
@@ -405,10 +421,6 @@ Set the string between condiftionals (C<for>, C<if>, C<while>...) and parenthesi
 
 =back
 
-=item get_str_between_conditional_and_parenthesis()
-
-Returns the string between condiftionals (C<for>, C<if>, C<while>...) and parenthesis.
-
 =item set_str_between_function_and_parenthesis(VALUE)
 
 Set the string between function name and its opening parenthesis. C<VALUE> is the value. Default value at initialization is C<''>. On error an exception C<Error::Simple> is thrown.
@@ -425,10 +437,6 @@ Set the string between function name and its opening parenthesis. C<VALUE> is th
 
 =back
 
-=item get_str_between_function_and_parenthesis()
-
-Returns the string between function name and its opening parenthesis.
-
 =item set_str_post_block_close_curl(VALUE)
 
 Set the string printed after the closing curly of a multi-line BLOCK. Any string C<__IND_BLOCK__> in the value is replaced with the correct block indentation. C<VALUE> is the value. Default value at initialization is C<"\n__IND_BLOCK__">. On error an exception C<Error::Simple> is thrown.
@@ -445,10 +453,6 @@ Set the string printed after the closing curly of a multi-line BLOCK. Any string
 
 =back
 
-=item get_str_post_block_close_curl()
-
-Returns the string printed after the closing curly of a multi-line BLOCK. Any string C<__IND_BLOCK__> in the value is replaced with the correct block indentation.
-
 =item set_str_pre_block_open_curl(VALUE)
 
 Set the string printed before the opening curly of a multi-line BLOCK. Any string C<__IND_BLOCK__> in the value is replaced with the correct block indentation. C<VALUE> is the value. Default value at initialization is C<' '>. On error an exception C<Error::Simple> is thrown.
@@ -465,10 +469,6 @@ Set the string printed before the opening curly of a multi-line BLOCK. Any strin
 
 =back
 
-=item get_str_pre_block_open_curl()
-
-Returns the string printed before the opening curly of a multi-line BLOCK. Any string C<__IND_BLOCK__> in the value is replaced with the correct block indentation.
-
 =back
 
 =head1 SEE ALSO
@@ -493,6 +493,7 @@ L<PerlBean::Described>,
 L<PerlBean::Described::ExportTag>,
 L<PerlBean::Method>,
 L<PerlBean::Method::Constructor>,
+L<PerlBean::Method::Factory>,
 L<PerlBean::Symbol>
 
 =head1 BUGS
@@ -502,6 +503,7 @@ None known (yet.)
 =head1 HISTORY
 
 First development: January 2003
+Last update: September 2003
 
 =head1 AUTHOR
 
@@ -548,12 +550,12 @@ sub _initialize {
     # Check $opt
     ref($opt) eq 'HASH' || throw Error::Simple("ERROR: PerlBean::Style::_initialize, first argument must be 'HASH' reference.");
 
-    # attribute_name_to_method_base_filter, SINGLE, with default value
-    $self->set_attribute_name_to_method_base_filter( exists( $opt->{attribute_name_to_method_base_filter} ) ? $opt->{attribute_name_to_method_base_filter} : $DEFAULT_VALUE{attribute_name_to_method_base_filter} );
-
     # indent, SINGLE, with default value
     $self->set_indent( exists( $opt->{indent} ) ? $opt->{indent} : $DEFAULT_VALUE{indent} );
 
+    # method_factory_name_to_method_base_filter, SINGLE, with default value
+    $self->set_method_factory_name_to_method_base_filter( exists( $opt->{method_factory_name_to_method_base_filter} ) ? $opt->{method_factory_name_to_method_base_filter} : $DEFAULT_VALUE{method_factory_name_to_method_base_filter} );
+
     # method_operation_filter, SINGLE, with default value
     $self->set_method_operation_filter( exists( $opt->{method_operation_filter} ) ? $opt->{method_operation_filter} : $DEFAULT_VALUE{method_operation_filter} );
 
@@ -582,275 +584,6 @@ sub _initialize {
     return($self);
 }
 
-sub default_attribute_name_to_method_base_filter {
-    return( '_' . shift );
-}
-
-sub default_method_operation_filter {
-    return(shift);
-}
-
-sub instance {
-    # Allow calls like:
-    # - PerlBean::Style::instance()
-    # - PerlBean::Style->instance()
-    # - $variable->instance()
-    if ( ref($_[0]) && &UNIVERSAL::isa( $_[0], 'PerlBean::Style' ) ) {
-        shift;
-    }
-    elsif ( ! ref($_[0]) && $_[0] eq 'PerlBean::Style' ) {
-        shift;
-    }
-
-    # If $SINGLETON is defined return it
-    defined($SINGLETON) && return($SINGLETON);
-
-    # Create the object and set $SINGLETON
-    $SINGLETON = PerlBean::Style->new();
-
-    # Initialize the object separately as the initialization might
-    # depend on $SINGLETON being set.
-    $SINGLETON->_initialize(@_);
-
-    # Return $SINGLETON
-    return($SINGLETON);
-}
-
-sub set_attribute_name_to_method_base_filter {
-    my $self = shift;
-    my $val = shift;
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'attribute_name_to_method_base_filter', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_attribute_name_to_method_base_filter, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{PerlBean_Style}{attribute_name_to_method_base_filter} = $val;
-
-    # Set export value only for the singleton object instance
-    return if ($self != $SINGLETON);
-
-    # Set $AN2MBF
-    $AN2MBF = $val;
-}
-
-sub get_attribute_name_to_method_base_filter {
-    my $self = shift;
-
-    return( $self->{PerlBean_Style}{attribute_name_to_method_base_filter} );
-}
-
-sub set_indent {
-    my $self = shift;
-    my $val = shift;
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'indent', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_indent, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{PerlBean_Style}{indent} = $val;
-
-    # Set export value only for the singleton object instance
-    return if ($self != $SINGLETON);
-
-    # Set $IND and call set_str_post_block_close_curl and
-    # set_str_pre_block_open_curl to (re)make @PBCC and @PBOC
-    $IND = $val;
-    $self->set_str_post_block_close_curl ( $self->get_str_post_block_close_curl() );
-    $self->set_str_pre_block_open_curl ( $self->get_str_pre_block_open_curl() );
-}
-
-sub get_indent {
-    my $self = shift;
-
-    return( $self->{PerlBean_Style}{indent} );
-}
-
-sub set_method_operation_filter {
-    my $self = shift;
-    my $val = shift;
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'method_operation_filter', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_method_operation_filter, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{PerlBean_Style}{method_operation_filter} = $val;
-
-    # Set export value only for the singleton object instance
-    return if ($self != $SINGLETON);
-
-    # Set $MOF
-    $MOF = $val;
-}
-
-sub get_method_operation_filter {
-    my $self = shift;
-
-    return( $self->{PerlBean_Style}{method_operation_filter} );
-}
-
-sub set_str_after_comma {
-    my $self = shift;
-    my $val = shift;
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'str_after_comma', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_str_after_comma, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{PerlBean_Style}{str_after_comma} = $val;
-
-    # Set export value only for the singleton object instance
-    return if ($self != $SINGLETON);
-
-    # Set $AC
-    $AC = $val;
-}
-
-sub get_str_after_comma {
-    my $self = shift;
-
-    return( $self->{PerlBean_Style}{str_after_comma} );
-}
-
-sub set_str_around_complex_subscripts {
-    my $self = shift;
-    my $val = shift;
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'str_around_complex_subscripts', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_str_around_complex_subscripts, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{PerlBean_Style}{str_around_complex_subscripts} = $val;
-
-    # Set export value only for the singleton object instance
-    return if ($self != $SINGLETON);
-
-    # Set $ACS
-    $ACS = $val;
-}
-
-sub get_str_around_complex_subscripts {
-    my $self = shift;
-
-    return( $self->{PerlBean_Style}{str_around_complex_subscripts} );
-}
-
-sub set_str_around_operators {
-    my $self = shift;
-    my $val = shift;
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'str_around_operators', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_str_around_operators, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{PerlBean_Style}{str_around_operators} = $val;
-
-    # Set export value only for the singleton object instance
-    return if ($self != $SINGLETON);
-
-    # Set $AO
-    $AO = $val;
-}
-
-sub get_str_around_operators {
-    my $self = shift;
-
-    return( $self->{PerlBean_Style}{str_around_operators} );
-}
-
-sub set_str_between_conditional_and_parenthesis {
-    my $self = shift;
-    my $val = shift;
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'str_between_conditional_and_parenthesis', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_str_between_conditional_and_parenthesis, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{PerlBean_Style}{str_between_conditional_and_parenthesis} = $val;
-
-    # Set export value only for the singleton object instance
-    return if ($self != $SINGLETON);
-
-    # Set $BCP
-    $BCP = $val;
-}
-
-sub get_str_between_conditional_and_parenthesis {
-    my $self = shift;
-
-    return( $self->{PerlBean_Style}{str_between_conditional_and_parenthesis} );
-}
-
-sub set_str_between_function_and_parenthesis {
-    my $self = shift;
-    my $val = shift;
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'str_between_function_and_parenthesis', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_str_between_function_and_parenthesis, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{PerlBean_Style}{str_between_function_and_parenthesis} = $val;
-
-    # Set export value only for the singleton object instance
-    return if ($self != $SINGLETON);
-
-    # Set $BFP
-    $BFP = $val;
-}
-
-sub get_str_between_function_and_parenthesis {
-    my $self = shift;
-
-    return( $self->{PerlBean_Style}{str_between_function_and_parenthesis} );
-}
-
-sub set_str_post_block_close_curl {
-    my $self = shift;
-    my $val = shift;
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'str_post_block_close_curl', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_str_post_block_close_curl, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{PerlBean_Style}{str_post_block_close_curl} = $val;
-
-    # Make @PBCC
-    for (my $i = 0; $i < 10; $i++) {
-        $PBCC[$i] = $val;
-        my $ind_block = $IND x $i;
-        $PBCC[$i] =~ s/__IND_BLOCK__/$ind_block/g;
-    }
-}
-
-sub get_str_post_block_close_curl {
-    my $self = shift;
-
-    return( $self->{PerlBean_Style}{str_post_block_close_curl} );
-}
-
-sub set_str_pre_block_open_curl {
-    my $self = shift;
-    my $val = shift;
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'str_pre_block_open_curl', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_str_pre_block_open_curl, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{PerlBean_Style}{str_pre_block_open_curl} = $val;
-
-    # Make @PBOC
-    for (my $i = 0; $i < 10; $i++) {
-        $PBOC[$i] = $val;
-        my $ind_block = $IND x $i;
-        $PBOC[$i] =~ s/__IND_BLOCK__/$ind_block/g;
-    }
-}
-
-sub get_str_pre_block_open_curl {
-    my $self = shift;
-
-    return( $self->{PerlBean_Style}{str_pre_block_open_curl} );
-}
-
 sub _value_is_allowed {
     my $name = shift;
 
@@ -894,3 +627,272 @@ sub _value_is_allowed {
     return(1);
 }
 
+sub default_method_factory_name_to_method_base_filter {
+    return( '_' . shift );
+}
+
+sub default_method_operation_filter {
+    return(shift);
+}
+
+sub get_indent {
+    my $self = shift;
+
+    return( $self->{PerlBean_Style}{indent} );
+}
+
+sub get_method_factory_name_to_method_base_filter {
+    my $self = shift;
+
+    return( $self->{PerlBean_Style}{method_factory_name_to_method_base_filter} );
+}
+
+sub get_method_operation_filter {
+    my $self = shift;
+
+    return( $self->{PerlBean_Style}{method_operation_filter} );
+}
+
+sub get_str_after_comma {
+    my $self = shift;
+
+    return( $self->{PerlBean_Style}{str_after_comma} );
+}
+
+sub get_str_around_complex_subscripts {
+    my $self = shift;
+
+    return( $self->{PerlBean_Style}{str_around_complex_subscripts} );
+}
+
+sub get_str_around_operators {
+    my $self = shift;
+
+    return( $self->{PerlBean_Style}{str_around_operators} );
+}
+
+sub get_str_between_conditional_and_parenthesis {
+    my $self = shift;
+
+    return( $self->{PerlBean_Style}{str_between_conditional_and_parenthesis} );
+}
+
+sub get_str_between_function_and_parenthesis {
+    my $self = shift;
+
+    return( $self->{PerlBean_Style}{str_between_function_and_parenthesis} );
+}
+
+sub get_str_post_block_close_curl {
+    my $self = shift;
+
+    return( $self->{PerlBean_Style}{str_post_block_close_curl} );
+}
+
+sub get_str_pre_block_open_curl {
+    my $self = shift;
+
+    return( $self->{PerlBean_Style}{str_pre_block_open_curl} );
+}
+
+sub instance {
+    # Allow calls like:
+    # - PerlBean::Style::instance()
+    # - PerlBean::Style->instance()
+    # - $variable->instance()
+    if ( ref($_[0]) && &UNIVERSAL::isa( $_[0], 'PerlBean::Style' ) ) {
+        shift;
+    }
+    elsif ( defined( $_[0] ) && ! ref( $_[0] ) && $_[0] eq 'PerlBean::Style' ) {
+        shift;
+    }
+
+    # If $SINGLETON is defined return it
+    defined($SINGLETON) && return($SINGLETON);
+
+    # Create the object and set $SINGLETON
+    $SINGLETON = PerlBean::Style->new();
+
+    # Initialize the object separately as the initialization might
+    # depend on $SINGLETON being set.
+    $SINGLETON->_initialize(@_);
+
+    # Return $SINGLETON
+    return($SINGLETON);
+}
+
+sub set_indent {
+    my $self = shift;
+    my $val = shift;
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'indent', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_indent, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{PerlBean_Style}{indent} = $val;
+
+    # Set export value only for the singleton object instance
+    return if ( ! defined( $SINGLETON ) || $self != $SINGLETON );
+
+    # Set $IND and call set_str_post_block_close_curl and
+    # set_str_pre_block_open_curl to (re)make @PBCC and @PBOC
+    $IND = $val;
+    $self->set_str_post_block_close_curl ( $self->get_str_post_block_close_curl() );
+    $self->set_str_pre_block_open_curl ( $self->get_str_pre_block_open_curl() );
+}
+
+sub set_method_factory_name_to_method_base_filter {
+    my $self = shift;
+    my $val = shift;
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'method_factory_name_to_method_base_filter', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_method_factory_name_to_method_base_filter, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{PerlBean_Style}{method_factory_name_to_method_base_filter} = $val;
+
+    # Set export value only for the singleton object instance
+    return if ( ! defined( $SINGLETON ) || $self != $SINGLETON );
+
+    # Set $AN2MBF
+    $AN2MBF = $val;
+}
+
+sub set_method_operation_filter {
+    my $self = shift;
+    my $val = shift;
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'method_operation_filter', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_method_operation_filter, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{PerlBean_Style}{method_operation_filter} = $val;
+
+    # Set export value only for the singleton object instance
+    return if ( ! defined( $SINGLETON ) || $self != $SINGLETON );
+
+    # Set $MOF
+    $MOF = $val;
+}
+
+sub set_str_after_comma {
+    my $self = shift;
+    my $val = shift;
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'str_after_comma', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_str_after_comma, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{PerlBean_Style}{str_after_comma} = $val;
+
+    # Set export value only for the singleton object instance
+    return if ( ! defined( $SINGLETON ) || $self != $SINGLETON );
+
+    # Set $AC
+    $AC = $val;
+}
+
+sub set_str_around_complex_subscripts {
+    my $self = shift;
+    my $val = shift;
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'str_around_complex_subscripts', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_str_around_complex_subscripts, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{PerlBean_Style}{str_around_complex_subscripts} = $val;
+
+    # Set export value only for the singleton object instance
+    return if ( ! defined( $SINGLETON ) || $self != $SINGLETON );
+
+    # Set $ACS
+    $ACS = $val;
+}
+
+sub set_str_around_operators {
+    my $self = shift;
+    my $val = shift;
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'str_around_operators', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_str_around_operators, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{PerlBean_Style}{str_around_operators} = $val;
+
+    # Set export value only for the singleton object instance
+    return if ( ! defined( $SINGLETON ) || $self != $SINGLETON );
+
+    # Set $AO
+    $AO = $val;
+}
+
+sub set_str_between_conditional_and_parenthesis {
+    my $self = shift;
+    my $val = shift;
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'str_between_conditional_and_parenthesis', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_str_between_conditional_and_parenthesis, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{PerlBean_Style}{str_between_conditional_and_parenthesis} = $val;
+
+    # Set export value only for the singleton object instance
+    return if ( ! defined( $SINGLETON ) || $self != $SINGLETON );
+
+    # Set $BCP
+    $BCP = $val;
+}
+
+sub set_str_between_function_and_parenthesis {
+    my $self = shift;
+    my $val = shift;
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'str_between_function_and_parenthesis', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_str_between_function_and_parenthesis, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{PerlBean_Style}{str_between_function_and_parenthesis} = $val;
+
+    # Set export value only for the singleton object instance
+    return if ( ! defined( $SINGLETON ) || $self != $SINGLETON );
+
+    # Set $BFP
+    $BFP = $val;
+}
+
+sub set_str_post_block_close_curl {
+    my $self = shift;
+    my $val = shift;
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'str_post_block_close_curl', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_str_post_block_close_curl, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{PerlBean_Style}{str_post_block_close_curl} = $val;
+
+    # Make @PBCC
+    for (my $i = 0; $i < 10; $i++) {
+        $PBCC[$i] = $val;
+        my $ind_block = $IND x $i;
+        $PBCC[$i] =~ s/__IND_BLOCK__/$ind_block/g;
+    }
+}
+
+sub set_str_pre_block_open_curl {
+    my $self = shift;
+    my $val = shift;
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'str_pre_block_open_curl', $val ) || throw Error::Simple("ERROR: PerlBean::Style::set_str_pre_block_open_curl, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{PerlBean_Style}{str_pre_block_open_curl} = $val;
+
+    # Make @PBOC
+    for (my $i = 0; $i < 10; $i++) {
+        $PBOC[$i] = $val;
+        my $ind_block = $IND x $i;
+        $PBOC[$i] =~ s/__IND_BLOCK__/$ind_block/g;
+    }
+}
+
