@@ -1,6 +1,8 @@
 #!/usr/bin/perl
 
 use strict;
+use lib '../blib/lib';
+use PerlBean::Style qw(:codegen);
 
 # Make a PerlBean collection
 use PerlBean::Collection;
@@ -41,6 +43,7 @@ my $circle = PerlBean->new ( {
     package => 'Circle',
     base => [ qw( Shape ) ],
     short_description => 'circle shape',
+    description => "circle shape\n",
     abstract => 'circle shape',
     autoloaded => 0,
 } );
@@ -48,24 +51,44 @@ $coll->add_perl_bean( $circle );
 
 # Make the Circle PerlBean radius attribute and add it to the Circle PerlBean
 my $radius = $fact->create_attribute( {
-    attribute_name => 'radius',
+    method_factory_name => 'radius',
     short_description => 'the shape\'s radius',
     allow_rx => [ qw( ^\d*(\.\d+)?$ ) ],
 } );
-$circle->add_attribute( $radius );
+$circle->add_method_factory( $radius );
 
 # Make the Circle area() method add it to the Circle PerlBean
 use PerlBean::Method;
+my $op = &{$MOF}('get');
+my $mb = $radius->get_method_base();
 my $area_circle = PerlBean::Method->new( {
     method_name => 'area',
     body => <<EOF,
     my \$self = shift;
 
-    return( 2 * 3.1415926 * \$self->get_radius() );
+    return( 2 * \$PI * \$self->$op$mb() );
 EOF
 } );
 $circle->add_method( $area_circle );
 
+# Make a PI symbol and add it to the Circle PerlBean
+my $symbol = PerlBean::Symbol->new( {
+    symbol_name => '$PI',
+    description => "The PI constant\n",
+    assignment => 3.14 . ";\n",
+    comment => "# The PI constant\n",
+    export_tag => [ qw( geo ) ],
+} );
+$circle->add_symbol( $symbol );
+
+# Make the geo export tag description and add it to the Circle PerlBean
+use PerlBean::Described::ExportTag;
+my $geo = PerlBean::Described::ExportTag->new( {
+    export_tag_name => 'geo',
+    description => "Geometric constants\n",
+} );
+$circle->add_export_tag_description( $geo );
+
 # Make the Square PerlBean and add it to the PerlBean collection
 my $square = PerlBean->new ( {
     package => 'Square',
@@ -78,20 +101,22 @@ $coll->add_perl_bean( $square );
 
 # Make the Square PerlBean width attribute and add it to the Square PerlBean
 my $width = $fact->create_attribute( {
-    attribute_name => 'width',
+    method_factory_name => 'width',
     short_description => 'the shape\'s width',
     allow_rx => [ qw( ^\d*(\.\d+)?$ ) ],
 } );
-$square->add_attribute( $width );
+$square->add_method_factory( $width );
 
 # Make the Square area() method add it to the Square PerlBean
 use PerlBean::Method;
+$op = &{$MOF}('get');
+$mb = $width->get_method_base();
 my $area_square = PerlBean::Method->new( {
     method_name => 'area',
     body => <<EOF,
     my \$self = shift;
 
-    return( \$self->get_width() * \$self->get_width() );
+    return( \$self->$op$mb() * \$self->$op$mb() );
 EOF
 } );
 $square->add_method( $area_square );
@@ -108,20 +133,23 @@ $coll->add_perl_bean( $rectangle );
 
 # Make the Rectangle PerlBean height attribute and add it to the the PerlBean
 my $height = $fact->create_attribute( {
-    attribute_name => 'height',
+    method_factory_name => 'height',
     short_description => 'the shape\'s height',
     allow_rx => [ qw( ^\d*(\.\d+)?$ ) ],
 } );
-$rectangle->add_attribute( $height );
+$rectangle->add_method_factory( $height );
 
 # Make the Rectangle area() method add it to the Rectangle PerlBean
 use PerlBean::Method;
+$op = &{$MOF}('get');
+$mb = $width->get_method_base();
+my $mb_height = $height->get_method_base();
 my $area_rectangle = PerlBean::Method->new( {
     method_name => 'area',
     body => <<EOF,
     my \$self = shift;
 
-    return( \$self->get_width() * \$self->get_height() );
+    return( \$self->$op$mb() * \$self->$op$mb_height() );
 EOF
 } );
 $rectangle->add_method( $area_rectangle );
@@ -137,3 +165,5 @@ mkdir($dir);
 
 # Write the collection
 $coll->write($dir);
+
+1;
